<html>
<?php
include("header.php");
$db = db_init();
$result =db_query("SELECT * FROM translators WHERE id=\"$id\"",$db);
$full=db_result($result,0,"first") . " " .db_result($result,0,"last");
echo "<h1>".gettext("Files maintained by")." $full</h1>";
$result2 =db_query("SELECT * FROM files WHERE idTranslator=\"$id\"",$db);
echo "<table>\n<tr><td>".gettext("File")."</td><td>".gettext("Package")."</td></tr>";
	while ($myrow =db_fetch_row($result2)) 
	{
		printf("<tr><td>$myrow[0]</td><td>$myrow[1]</td></tr>\n");
	}
echo "</table>";
include("footer.php");
?>
</body>
</html>
